from __future__ import absolute_import
#
# ir - Consumer infrared operations package.
#
# This is a notionally abstract object harness for representing
# "Consumer IR" (aka "remote control") signals. At this (top) level,
# we don't talk any particular vendor's language, but we do assume
# that we're dealing with the usual stuff (PWM on a fixed carrier frequency).
#
# Vocabulary:
# Carrier: A fixed carrier frequency for a particular IR emitter.
# Pulse: a contiguous run of "on" transitions followed by a contiguous run
#	of "off" transitions, counted by (integer) carrier transits.
# Pulse Train: a sequence of Pulses without intervening pauses.
# Event: A carrier frequency and Pulse Train performed in time.
# IR Type: A way of encoding Event data.
# Code: An Event understood and interpreted by a particular Type.
# Symbol: A Code pattern, used to recognize or generate a Code.
#
# Each Type has its own way to turn Events into Codes and Symbols.
# There is a Generic Type that "recognizes" any Event and produces
# Codes and Symbols that contain raw Pulse Trains. Other Types are
# more compact and meaningful, but only deal with their kinds of Codes.
#
# This file provides completely abstract base classes for these concepts.
# Actual receiver devices deliver subclasses of Event, but are expected
# to be able to send any subclass of Code. Not all Event subclasses are
# "real" hardware; some are just adapters to external representations
# (e.g. the popular "Pronto" style hex files).
#
# Copyright 2010-2016 Perry The Cynic. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# Collect selected parts of the base package
#
from ir.core import Pulse, Error
from ir.core import Symbol, Code, Event
from ir.core import Receiver

#
# Roll up standard IR types
#
from ir import type
